@@ -134,7 +134,7 @@ module Transform = struct
       Some { first with loc_end = last.loc_end }
   ;;
 
-  let merge_into_generic_mappers t ~hook ~expect_mismatch_handler ~omp_config =
+  let merge_into_generic_mappers t ~hook ~expect_mismatch_handler ~tool_name =
     let { rules; enclose_impl; enclose_intf; impl; intf; _ } = t in
     let map =
       new Context_free.map_top_down rules
@@ -180,7 +180,7 @@ module Transform = struct
             gen_header_and_footer Structure_item whole_loc f
         in
         let file_path = File_path.get_default_path_str st in
-        let base_ctxt = Expansion_context.Base.top_level ~omp_config ~file_path in
+        let base_ctxt = Expansion_context.Base.top_level ~tool_name ~file_path in
         let attrs = map#structure base_ctxt attrs in
         let st = map#structure base_ctxt st in
         List.concat [ attrs; header; st; footer ]
@@ -204,7 +204,7 @@ module Transform = struct
             gen_header_and_footer Signature_item whole_loc f
         in
         let file_path = File_path.get_default_path_sig sg in
-        let base_ctxt = Expansion_context.Base.top_level ~omp_config ~file_path in
+        let base_ctxt = Expansion_context.Base.top_level ~tool_name ~file_path in
         let attrs = map#signature base_ctxt attrs in
         let sg = map#signature base_ctxt sg in
         List.concat [ attrs; header; sg; footer ]
@@ -313,7 +313,7 @@ let debug_dropped_attribute name ~old_dropped ~new_dropped =
   print_diff "reappeared"  old_dropped new_dropped
 ;;
 
-let get_whole_ast_passes ~hook ~expect_mismatch_handler ~omp_config =
+let get_whole_ast_passes ~hook ~expect_mismatch_handler ~tool_name =
   let cts =
     match !apply_list with
     | None -> List.rev !Transform.all
@@ -332,7 +332,7 @@ let get_whole_ast_passes ~hook ~expect_mismatch_handler ~omp_config =
   end;
   let cts =
     if !no_merge then
-      List.map cts ~f:(Transform.merge_into_generic_mappers ~hook ~omp_config
+      List.map cts ~f:(Transform.merge_into_generic_mappers ~hook ~tool_name
                          ~expect_mismatch_handler)
     else begin
       let get_enclosers ~f =
@@ -369,7 +369,7 @@ let get_whole_ast_passes ~hook ~expect_mismatch_handler ~omp_config =
         Transform.builtin_of_context_free_rewriters ~rules ~hook ~expect_mismatch_handler
           ~enclose_impl:(merge_encloser impl_enclosers)
           ~enclose_intf:(merge_encloser intf_enclosers)
-          ~omp_config
+          ~tool_name
         :: cts
     end
   in linters @ preprocess @ List.filter cts ~f:(fun (ct : Transform.t) ->
@@ -379,8 +379,8 @@ let get_whole_ast_passes ~hook ~expect_mismatch_handler ~omp_config =
 ;;
 
 let apply_transforms
-      ~omp_config ~field ~lint_field ~dropped_so_far ~hook ~expect_mismatch_handler x =
-  let cts = get_whole_ast_passes ~omp_config ~hook ~expect_mismatch_handler in
+      ~tool_name ~field ~lint_field ~dropped_so_far ~hook ~expect_mismatch_handler x =
+  let cts = get_whole_ast_passes ~tool_name ~hook ~expect_mismatch_handler in
   let x, _dropped, lint_errors =
   List.fold_left cts ~init:(x, [], [])
     ~f:(fun (x, dropped, lint_errors) (ct : Transform.t) ->
@@ -455,10 +455,10 @@ let as_ppx_config () =
     ?for_package:!Ocaml_common.Clflags.for_package
 
 let print_passes () =
+  let tool_name = "ppxlib_driver" in
   let hook = Context_free.Generated_code_hook.nop in
   let expect_mismatch_handler = Context_free.Expect_mismatch_handler.nop in
-  let omp_config = config ~hook ~expect_mismatch_handler in
-  let cts = get_whole_ast_passes ~hook ~expect_mismatch_handler ~omp_config in
+  let cts = get_whole_ast_passes ~hook ~expect_mismatch_handler ~tool_name in
   if !perform_checks then
     printf "<builtin:freshen-and-collect-attributes>\n";
   List.iter cts ~f:(fun ct -> printf "%s\n" ct.Transform.name);
@@ -480,7 +480,7 @@ let real_map_structure config cookies st =
   end;
   let st, lint_errors =
     apply_transforms st
-      ~omp_config:config
+      ~tool_name:config.Migrate_parsetree.Driver.tool_name
       ~field:(fun (ct : Transform.t) -> ct.impl)
       ~lint_field:(fun (ct : Transform.t) -> ct.lint_impl)
       ~dropped_so_far:Attribute.dropped_so_far_structure ~hook ~expect_mismatch_handler
@@ -528,7 +528,7 @@ let real_map_signature config cookies sg =
   end;
   let sg, lint_errors =
     apply_transforms sg
-      ~omp_config:config
+      ~tool_name:config.Migrate_parsetree.Driver.tool_name
       ~field:(fun (ct : Transform.t) -> ct.intf)
       ~lint_field:(fun (ct : Transform.t) -> ct.lint_intf)
       ~dropped_so_far:Attribute.dropped_so_far_signature ~hook ~expect_mismatch_handler
@@ -1323,3 +1323,8 @@ let enable_location_check () =
 
 let disable_location_check () =
   perform_locations_check := false
+
+let map_structure st =
+  map_structure st
+  |> Migrate_parsetree.Driver.migrate_some_structure
+       (module Ppxlib_ast.Selected_ast)
